.. _unemployees:

Unemployment: Your source of idle workers
=========================================

Unemployees are what normal folks call workers, but we just had to be special,
and it had to fit the analogy.

.. toctree::

   base
   app
   handlers
   examples
